@@ -12,12 +12,9 @@ from django.db.models.constraints import UniqueConstraint
 from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
 
-from allauth.account import app_settings, signals
+from allauth.account import app_settings
 from allauth.account.adapter import get_adapter
-from allauth.account.managers import (
-    EmailAddressManager,
-    EmailConfirmationManager,
-)
+from allauth.account.managers import EmailAddressManager, EmailConfirmationManager
 
 
 class EmailAddress(models.Model):
@@ -125,21 +122,15 @@ class EmailAddress(models.Model):
 
 class EmailConfirmationMixin:
     def confirm(self, request) -> Optional[EmailAddress]:
+        from allauth.account.internal.flows.email_verification import (
+            mark_email_address_as_verified,
+        )
+
         email_address = self.email_address  # type: ignore[attr-defined]
-        if not email_address.verified:
-            confirmed = get_adapter().confirm_email(request, email_address)
-            if confirmed:
-                return email_address
-        return None
+        return mark_email_address_as_verified(request, email_address)
 
     def send(self, request=None, signup=False) -> None:
         get_adapter().send_confirmation_mail(request, self, signup)
-        signals.email_confirmation_sent.send(
-            sender=self.__class__,
-            request=request,
-            confirmation=self,
-            signup=signup,
-        )
 
 
 class EmailConfirmation(EmailConfirmationMixin, models.Model):
@@ -240,6 +231,7 @@ class Login:
     signal_kwargs: Optional[Dict]
     signup: bool
     email: Optional[str]
+    phone: Optional[str]
     state: Dict
     initiated_at: float
     redirect_url: Optional[str]
@@ -254,6 +246,7 @@ class Login:
         email: Optional[str] = None,
         state: Optional[Dict] = None,
         initiated_at: Optional[float] = None,
+        phone: Optional[str] = None,
     ):
         self.user = user
         if not email_verification:
@@ -263,6 +256,7 @@ class Login:
         self.signal_kwargs = signal_kwargs
         self.signup = signup
         self.email = email
+        self.phone = phone
         self.state = {} if state is None else state
         self.initiated_at = initiated_at if initiated_at else time.time()
 
@@ -283,6 +277,7 @@ class Login:
             "signup": self.signup,
             "redirect_url": self.redirect_url,
             "email": self.email,
+            "phone": self.phone,
             "signal_kwargs": signal_kwargs,
             "state": self.state,
             "initiated_at": self.initiated_at,
@@ -314,6 +309,8 @@ class Login:
                 user=user,
                 email_verification=data["email_verification"],
                 redirect_url=data["redirect_url"],
+                email=data["email"],
+                phone=data["phone"],
                 signup=data["signup"],
                 signal_kwargs=signal_kwargs,
                 state=data["state"],
@@ -325,11 +322,7 @@ class Login:
 
 def get_emailconfirmation_model():
     if app_settings.EMAIL_VERIFICATION_BY_CODE_ENABLED:
-        from allauth.account.internal.flows.email_verification_by_code import (
-            EmailVerificationModel,
-        )
-
-        return EmailVerificationModel
+        raise NotImplementedError
     elif app_settings.EMAIL_CONFIRMATION_HMAC:
         model = EmailConfirmationHMAC
     else:
